@@ -135,5 +135,66 @@ utils::globalVariables(c('ADJ_FACTOR_MACR', 'ADJ_FACTOR_MICR', 'ADJ_FACTOR_SUBP'
                          'PREV_BAA', 'PREV_BAA_ga', 'PREV_TPA', 'PREV_TPA_ga', 'Q1', 'RECR_RATE', 'RECR_RATE_SE',
                          'RECR_RATE_ga', 'RECR_TPA_ga', 'REMV_TPA_ga', 'S1', 'STATUSCD', 'STATUSCD.prev',
                          'SUST_INDEX', 'SUST_INDEX_SE', 'TPA_UNADJ.prev', 'cvEst_q', 'cvStrat_q', 'lPlot', 'nLive',
-                         'nStems', 'qEst', 'qStrat', 'qVar', 'qv', 'x_ga', 'y', 'y_ga'
+                         'nStems', 'qEst', 'qStrat', 'qVar', 'qv', 'x_ga', 'y', 'y_ga',
+                         'BAA1', 'BAA2', 'BAA_RATE_INT', 'BAA_STATUS', 'CHNG_BAA','CHNG_BAA_SE', 'CHNG_TPA',
+                         'CHNG_TPA_SE', 'DIA_MIDPT', 'M_TPA', 'PLOT_STATUS_CD1', 'PLOT_STATUS_CD2', 'PREVDIA',
+                         'PREV_BAA_SE', 'PREV_HARV_BAA', 'PREV_MORT_BAA', 'PREV_TPA_SE', 'PREV_TRE_CN',
+                         'RECR_BAA', 'REMV_BAA', 'R_TPA', 'SI_STATUS', 'TPA_RATE', 'TPA_RATE_INT', 'TPA_RATE_SE',
+                         'TPA_STATUS', 'TPA_UNADJ1', 'TPA_UNADJ2', 'T_TPA', 'cb', 'cbPlot', 'cbStrat', 'cbVar', 'cbv', 'ct',
+                         'cvEst_cb', 'cvStrat_cb', 'pb', 'pbEst', 'pbPlot', 'pbStrat', 'pbVar', 'pbv', 'pt', 'ptEst', 'ptPlot',
+                         'ptStrat', 'ptVar', 'ptv', 'tDI1', 'tDI2', 'AGENTCD', 'ANIMAL', 'ANIMAL_RATE', 'ANIMAL_RATE_SE',
+                         'BUG', 'BUG_RATE', 'DISEASE',
+                         'DISEASE_RATE', 'DISEASE_RATE_SE', 'FIRE', 'FIRE_RATE', 'FIRE_RATE_SE', 'INSECT_RATE',
+                         'INSECT_RATE_SE', 'MORTYR', 'SILV', 'SILV_RATE', 'SILV_RATE_SE', 'UNKNOWN',
+                         'UNKNOWN_RATE', 'UNKNOWN_RATE_SE', 'VEG', 'VEG_RATE', 'VEG_RATE_SE', 'WEATHER',
+                         'WEATHER_RATE', 'WEATHER_RATE_SE', 'animal', 'animalEst', 'animalPlot', 'animalStrat',
+                         'animalVar', 'animalv', 'bug', 'bugEst', 'bugPlot', 'bugStrat', 'bugVar', 'bugv',
+                         'cvEst_animal', 'cvEst_bug', 'cvEst_disease', 'cvEst_fire', 'cvEst_silv', 'cvEst_un',
+                         'cvEst_veg', 'cvEst_weather', 'cvStrat_animal', 'cvStrat_bug', 'cvStrat_disease',
+                         'cvStrat_fire', 'cvStrat_silv', 'cvStrat_un', 'cvStrat_veg', 'cvStrat_weather',
+                         'disease', 'diseaseEst', 'diseasePlot', 'diseaseStrat', 'diseaseVar', 'diseasev', 'fire',
+                         'fireEst', 'firePlot', 'fireStrat', 'fireVar', 'firev', 'silv', 'silvEst', 'silvPlot',
+                         'silvStrat', 'silvVar', 'silvv', 'unEst', 'unPlot', 'unStrat', 'unVar', 'unknown', 'unv', 'veg',
+                         'vegEst', 'vegPlot', 'vegStrat', 'vegVar', 'vegv', 'weather', 'weatherEst', 'weatherPlot',
+                         'weatherStrat', 'weatherVar', 'weatherv',   'ALL_SEV', 'ALL_SEV_SE', 'DROUGHT_SEV', 'DROUGHT_SEV_SE', 'GROW_ALL_SEV',
+                         'GROW_ALL_SEV_SE', 'GROW_DROUGHT_SEV', 'GROW_DROUGHT_SEV_SE', 'GROW_WET_SEV',
+                         'GROW_WET_SEV_SE', 'WET_SEV', 'WET_SEV_SE', 'all_sev', 'cvEst_a', 'cvEst_gd', 'cvEst_gw',
+                         'cvEst_w', 'cvStrat_a', 'cvStrat_gd', 'cvStrat_gw', 'cvStrat_w', 'drought_sev', 'faEst',
+                         'faStrat', 'faVar', 'fav', 'gdEst', 'gdStrat', 'gdVar', 'gdv', 'grow_all_sev',
+                         'grow_drought_sev', 'grow_wet_sev', 'gwEst', 'gwStrat', 'gwVar', 'gwv', 'wEst', 'wStrat',
+                         'wVar', 'wet_sev', 'wv', 'MORT', 'STATUSCD1', 'STATUSCD2', 'cvEst_mort', 'cvStrat_mort', 'mort', 'mortEst',
+                         'mortPlot', 'mortStrat', 'mortVar', 'mortv',
+                         'GROW_TMAX_ANOM', 'GROW_TMAX_ANOM_SE', 'GROW_TMEAN_ANOM', 'GROW_TMEAN_ANOM_SE',
+                         'GROW_VPD_ANOM', 'GROW_VPD_ANOM_SE', 'TMAX_ANOM', 'TMAX_ANOM_SE', 'TMEAN_ANOM',
+                         'TMEAN_ANOM_SE', 'VPD_ANOM', 'VPD_ANOM_SE', 'cvEst_gtmax', 'cvEst_gtmean',
+                         'cvEst_gvpd', 'cvEst_tmax', 'cvEst_tmean', 'cvEst_vpd', 'cvStrat_gtmax',
+                         'cvStrat_gtmean', 'cvStrat_gvpd', 'cvStrat_tmax', 'cvStrat_tmean', 'cvStrat_vpd',
+                         'grow_tmax_anom', 'grow_tmean_anom', 'grow_vpd_anom', 'gtmaxEst', 'gtmaxStrat',
+                         'gtmaxVar', 'gtmaxv', 'gtmeanEst', 'gtmeanStrat', 'gtmeanVar', 'gtmeanv', 'gvpdEst',
+                         'gvpdStrat', 'gvpdVar', 'gvpdv', 'tmaxEst', 'tmaxStrat', 'tmaxVar', 'tmax_anom', 'tmaxv',
+                         'tmeanEst', 'tmeanStrat', 'tmeanVar', 'tmean_anom', 'tmeanv', 'vpdEst', 'vpdStrat', 'vpdVar',
+                         'vpd_anom', 'vpdv', 'CURR_BAA', 'CURR_TPA', 'SUST_INDEX_INT', 'cvEst_si', 'cvStrat_si', 'siEst', 'siPlot',
+                         'siStrat', 'siVar', 'siv', 'BAA_CHNG_PERC', 'BAA_MORT', 'BAA_MORT_SE', 'BAA_RECR', 'BAA_RECR_SE', 'ELEV ELEV_SE',
+                         'SI', 'SI_INT', 'SI_SE', 'SURV', 'TPA_CHNG_PERC', 'TPA_MORT', 'TPA_MORT_SE', 'TPA_RECR',
+                         'TPA_RECR_SE', 'bgrow', 'bgrowEst', 'bgrowStrat', 'bgrowVar', 'bgrowv', 'bmort', 'bmortEst',
+                         'bmortStrat', 'bmortVar', 'bmortv', 'brecr', 'brecrEst', 'brecrStrat', 'brecrVar', 'brecrv',
+                         'cvEst_bgrow', 'cvEst_bmort', 'cvEst_brecr', 'cvEst_elev', 'cvEst_tmort',
+                         'cvEst_trecr', 'cvStrat_bgrow', 'cvStrat_bmort', 'cvStrat_brecr', 'cvStrat_elev',
+                         'cvStrat_tmort', 'cvStrat_trecr', 'elevEst', 'elevStrat', 'elevVar', 'elevv', 'tmort',
+                         'tmortEst', 'tmortStrat', 'tmortVar', 'tmortv', 'trecr', 'trecrEst', 'trecrStrat',
+                         'ALSTK', 'BAA_RATE_VAR', 'ELEV', 'ELEV_SE', 'Eh_a_species', 'Eh_a_species_SE',
+                         'Eh_a_struct', 'Eh_a_struct_SE', 'Eh_b_species', 'Eh_b_struct', 'Eh_g_species',
+                         'Eh_g_struct', 'Eh_species', 'Eh_struct', 'H_a_species', 'H_a_species_SE',
+                         'H_a_struct', 'H_a_struct_SE', 'H_b_species', 'H_b_struct', 'H_g_species',
+                         'H_g_struct', 'H_species', 'H_struct', 'N', 'SI_VAR', 'SPCD1', 'SPCD2', 'STOCKING',
+                         'STOCKING_SE', 'S_a_species', 'S_a_species_SE', 'S_a_struct', 'S_a_struct_SE',
+                         'S_b_species', 'S_b_struct', 'S_g_species', 'S_g_struct', 'S_species', 'S_struct',
+                         'TPA_RATE_VAR', 'baaMean', 'baaSD', 'cvEst_esp', 'cvEst_est', 'cvEst_hsp', 'cvEst_hst',
+                         'cvEst_ssp', 'cvEst_sst', 'cvEst_stk', 'cvStrat_esp', 'cvStrat_est', 'cvStrat_hsp',
+                         'cvStrat_hst', 'cvStrat_ssp', 'cvStrat_sst', 'cvStrat_stk', 'espEst', 'espStrat',
+                         'espVar', 'espv', 'estEst', 'estStrat', 'estVar', 'estv', 'hspEst', 'hspStrat', 'hspVar', 'hspv',
+                         'hstEst', 'hstStrat', 'hstVar', 'hstv', 'htClass', 'minLive', 'nTotal', 'qt', 'sd', 'sspEst',
+                         'sspStrat', 'sspVar', 'sspv', 'sstEst', 'sstStrat', 'sstVar', 'sstv', 'stkEst', 'stkStrat',
+                         'stkVar', 'stkv', 'tpaMean', 'tpaSD', 'trecrVar', 'trecrv', 'ymax', 'ymin'
+
 ))
